4 ms·
Same question here. From one to eight threads typically doesn't account for 8x reduction directly. So if it's ten times faster, then I'd assume a single threade
by kreetx 2y ago
Same question here. From one to eight threads typically doesn't account for 8x reduction directly. So if it's ten times faster, then I'd assume a single threaded Rust version made it at least twice as fast. Though I'd wager that a rewrite in Python, now starting out with full knowledge of the problem domain, would have likely also improved performance.